
0.4.7 (2016-01-23)
##################

Changes since 0.4.6 (2016-06-27).

Bug Fixes
$$$$$$$$$

* fixes `#310 <https://github.com/biocommons/hgvs/issues/310/>`_: Fix wrong start position when normalizing some variants [`BROKEN: 734c08f18ea1 <https://github.com/biocommons/hgvs/commit/734c08f18ea1>`_]. Thanks to Meng Wang.
